CREATE TABLE `preferences` (
  `preferences_id` INT(18) UNSIGNED NOT NULL AUTO_INCREMENT,
  `full_name` VARCHAR(255) NULL,
  `email_address` VARCHAR(255) NOT NULL,
  `listed_in_searches` INT(1) UNSIGNED NULL,
  `portrait` LONGBLOB NULL,
  PRIMARY KEY(`preferences_id`)
)
TYPE=InnoDB;

CREATE TABLE `session` (
  `session_id` INT(18) UNSIGNED NOT NULL AUTO_INCREMENT,
  `key` CHAR(32) NOT NULL,
  `expiry` INT(11) UNSIGNED NOT NULL,
  `value` TEXT NOT NULL,
  PRIMARY KEY(`session_id`)
)
TYPE=InnoDB;

CREATE TABLE `user` (
  `user_id` INT(18) UNSIGNED NOT NULL AUTO_INCREMENT,
  `preferences_id` INT(18) UNSIGNED NOT NULL,
  `session_id` INT(18) UNSIGNED NULL,
  `username` VARCHAR(19) NOT NULL,
  `password` VARCHAR(9) NOT NULL,
  PRIMARY KEY(`user_id`, `preferences_id`),
  INDEX `user_FKIndex1`(`preferences_id`),
  INDEX `user_FKIndex2`(`session_id`),
  FOREIGN KEY(`preferences_id`)
    REFERENCES `preferences`(`preferences_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION,
  FOREIGN KEY(`session_id`)
    REFERENCES `session`(`session_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE `folder` (
  `folder_id` INT(18) UNSIGNED NOT NULL AUTO_INCREMENT,
  `preferences_id` INT(18) UNSIGNED NOT NULL,
  `user_id` INT(18) UNSIGNED NOT NULL,
  `short_name` VARCHAR(30) NOT NULL,
  `title` VARCHAR(255) NOT NULL,
  `description` VARCHAR(255) NULL,
  PRIMARY KEY(`folder_id`, `preferences_id`, `user_id`),
  INDEX `folder_FKIndex1`(`user_id`, `preferences_id`),
  FOREIGN KEY(`user_id`, `preferences_id`)
    REFERENCES `user`(`user_id`, `preferences_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE `message` (
  `message_id` INT(18) NOT NULL AUTO_INCREMENT,
  `preferences_id` INT(18) UNSIGNED NOT NULL,
  `user_id` INT(18) UNSIGNED NOT NULL,
  `folder_id` INT UNSIGNED NULL,
  `title` VARCHAR(255) NULL,
  `message` VARCHAR(255) NULL,
  PRIMARY KEY(`message_id`, `preferences_id`, `user_id`),
  INDEX `message_FKIndex1`(`folder_id`, `preferences_id`, `user_id`),
  INDEX `message_FKIndex2`(`user_id`, `preferences_id`),
  FOREIGN KEY(`folder_id`, `preferences_id`, `user_id`)
    REFERENCES `folder`(`folder_id`, `preferences_id`, `user_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION,
  FOREIGN KEY(`user_id`, `preferences_id`)
    REFERENCES `user`(`user_id`, `preferences_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE `news_item` (
  `news_item_id` INT(18) NOT NULL AUTO_INCREMENT,
  `preferences_id` INT(18) UNSIGNED NOT NULL,
  `user_id` INT(18) UNSIGNED NOT NULL,
  `folder_id` INT(18) UNSIGNED NULL,
  `short_name` VARCHAR(30) NOT NULL,
  `headline` VARCHAR(255) NOT NULL,
  `lead_in` VARCHAR(255) NULL,
  `body_text` LONGTEXT NULL,
  PRIMARY KEY(`news_item_id`, `preferences_id`, `user_id`),
  INDEX `news_item_FKIndex1`(`user_id`, `preferences_id`),
  INDEX `news_item_FKIndex2`(`folder_id`, `preferences_id`, `user_id`),
  FOREIGN KEY(`user_id`, `preferences_id`)
    REFERENCES `user`(`user_id`, `preferences_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION,
  FOREIGN KEY(`folder_id`, `preferences_id`, `user_id`)
    REFERENCES `folder`(`folder_id`, `preferences_id`, `user_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE `link` (
  `link_id` INT(18) UNSIGNED NOT NULL AUTO_INCREMENT,
  `preferences_id` INT(18) UNSIGNED NOT NULL,
  `user_id` INT(18) UNSIGNED NOT NULL,
  `folder_id` INT(18) UNSIGNED NULL,
  `short_name` VARCHAR(30) NOT NULL,
  `title` VARCHAR(255) NOT NULL,
  `description` VARCHAR(255) NULL,
  `url` VARCHAR(255) NOT NULL,
  PRIMARY KEY(`link_id`, `preferences_id`, `user_id`),
  INDEX `link_FKIndex1`(`folder_id`, `preferences_id`, `user_id`),
  INDEX `link_FKIndex2`(`user_id`, `preferences_id`),
  FOREIGN KEY(`folder_id`, `preferences_id`, `user_id`)
    REFERENCES `folder`(`folder_id`, `preferences_id`, `user_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION,
  FOREIGN KEY(`user_id`, `preferences_id`)
    REFERENCES `user`(`user_id`, `preferences_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE `event` (
  `event_id` INT(18) UNSIGNED NOT NULL AUTO_INCREMENT,
  `preferences_id` INT(18) UNSIGNED NOT NULL,
  `user_id` INT(18) UNSIGNED NOT NULL,
  `folder_id` INT(18) UNSIGNED NULL,
  `short_name` VARCHAR(30) NOT NULL,
  `title` VARCHAR(255) NOT NULL,
  `event_location` VARCHAR(255) NULL,
  `event_type` ENUM('Appointment','Convention','Meeting','Social
Event','Work') NULL,
  `description` VARCHAR(255) NULL,
  `event_url` VARCHAR(255) NULL,
  `event_starts` DATETIME NOT NULL,
  `event_ends` DATETIME NOT NULL,
  `contact_name` VARCHAR(255) NULL,
  `contact_email` VARCHAR(255) NULL,
  `contact_phone` VARCHAR(255) NULL,
  PRIMARY KEY(`event_id`, `preferences_id`, `user_id`),
  INDEX `event_FKIndex1`(`folder_id`, `preferences_id`, `user_id`),
  INDEX `event_FKIndex2`(`user_id`, `preferences_id`),
  FOREIGN KEY(`folder_id`, `preferences_id`, `user_id`)
    REFERENCES `folder`(`folder_id`, `preferences_id`, `user_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION,
  FOREIGN KEY(`user_id`, `preferences_id`)
    REFERENCES `user`(`user_id`, `preferences_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE `document` (
  `document_id` INT(18) UNSIGNED NOT NULL AUTO_INCREMENT,
  `preferences_id` INT(18) UNSIGNED NOT NULL,
  `user_id` INT(18) UNSIGNED NOT NULL,
  `folder_id` INT(18) UNSIGNED NULL,
  `short_name` VARCHAR(30) NOT NULL,
  `title` VARCHAR(255) NOT NULL,
  `description` VARCHAR(255) NULL,
  `body_text` LONGTEXT NULL,
  `upload_contents` LONGBLOB NULL,
  PRIMARY KEY(`document_id`, `preferences_id`, `user_id`),
  INDEX `document_FKIndex1`(`folder_id`, `preferences_id`, `user_id`),
  INDEX `document_FKIndex2`(`user_id`, `preferences_id`),
  FOREIGN KEY(`folder_id`, `preferences_id`, `user_id`)
    REFERENCES `folder`(`folder_id`, `preferences_id`, `user_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION,
  FOREIGN KEY(`user_id`, `preferences_id`)
    REFERENCES `user`(`user_id`, `preferences_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE `file` (
  `file_id` INT(18) UNSIGNED NOT NULL AUTO_INCREMENT,
  `preferences_id` INT(18) UNSIGNED NOT NULL,
  `user_id` INT(18) UNSIGNED NOT NULL,
  `folder_id` INT(18) UNSIGNED NULL,
  `title` VARCHAR(255) NULL,
  `description` VARCHAR(255) NULL,
  `file` LONGBLOB NOT NULL,
  PRIMARY KEY(`file_id`, `preferences_id`, `user_id`),
  INDEX `file_FKIndex1`(`folder_id`, `preferences_id`, `user_id`),
  INDEX `file_FKIndex2`(`user_id`, `preferences_id`),
  FOREIGN KEY(`folder_id`, `preferences_id`, `user_id`)
    REFERENCES `folder`(`folder_id`, `preferences_id`, `user_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION,
  FOREIGN KEY(`user_id`, `preferences_id`)
    REFERENCES `user`(`user_id`, `preferences_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE `image` (
  `image_id` INT(18) UNSIGNED NOT NULL AUTO_INCREMENT,
  `preferences_id` INT(18) UNSIGNED NOT NULL,
  `user_id` INT(18) UNSIGNED NOT NULL,
  `folder_id` INT(18) UNSIGNED NULL,
  `short_name` VARCHAR(30) NOT NULL,
  `title` VARCHAR(255) NOT NULL,
  `description` VARCHAR(255) NULL,
  `image` LONGBLOB NOT NULL,
  PRIMARY KEY(`image_id`, `preferences_id`, `user_id`),
  INDEX `image_FKIndex1`(`folder_id`, `preferences_id`, `user_id`),
  INDEX `image_FKIndex2`(`user_id`, `preferences_id`),
  FOREIGN KEY(`folder_id`, `preferences_id`, `user_id`)
    REFERENCES `folder`(`folder_id`, `preferences_id`, `user_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION,
  FOREIGN KEY(`user_id`, `preferences_id`)
    REFERENCES `user`(`user_id`, `preferences_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE `folder_relation` (
  `folder_relation_id` INT(18) UNSIGNED NOT NULL AUTO_INCREMENT,
  `folder_id_from` INT(18) UNSIGNED NOT NULL,
  `folder_id_to` INT(18) UNSIGNED NOT NULL,
  PRIMARY KEY(`folder_relation_id`, `user_id`, `preferences_id`,
`folder_id`),
  INDEX `folder_relation_FKIndex1`(`folder_id_from`),
  INDEX `folder_relation_FKIndex2`(`folder_id_to`),
  FOREIGN KEY(`folder_id_from`)
    REFERENCES `folder`(`folder_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION,
  FOREIGN KEY(`folder_id_to`)
    REFERENCES `folder`(`folder_id`)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
)
TYPE=InnoDB;